@@ -143,14 +143,15 @@ class CScreenBuilder {
 		// calculate time
 		$this->profileIdx = !empty($options['profileIdx']) ? $options['profileIdx'] : '';
 		$this->profileIdx2 = !empty($options['profileIdx2']) ? $options['profileIdx2'] : null;
-		$this->updateProfile = isset($options['updateProfile']) ? $options['updateProfile'] : true;
+		$this->updateProfile = array_key_exists('updateProfile', $options) ? $options['updateProfile'] : false;
 
-		$this->timeline = CScreenBase::calculateTime([
+		$this->timeline = calculateTime([
 			'profileIdx' => $this->profileIdx,
 			'profileIdx2' => $this->profileIdx2,
 			'updateProfile' => $this->updateProfile,
-			'period' => !empty($options['period']) ? $options['period'] : null,
-			'stime' => !empty($options['stime']) ? $options['stime'] : null
+			'period' => array_key_exists('period', $options) ? $options['period'] : null,
+			'stime' => array_key_exists('stime', $options) ? $options['stime'] : null,
+			'isNow' => array_key_exists('isNow', $options) ? $options['isNow'] : null
 		]);
 	}
 
@@ -190,9 +191,13 @@ class CScreenBuilder {
 				$options['screenitem'] = reset($options['screenitem']);
 			}
 
-			if (array_key_exists('screenitem', $options) && array_key_exists('resourcetype', $options['screenitem'])) {
+			if (is_array($options['screenitem']) && array_key_exists('screenitem', $options)
+					&& array_key_exists('resourcetype', $options['screenitem'])) {
 				$options['resourcetype'] = $options['screenitem']['resourcetype'];
 			}
+			else {
+				return null;
+			}
 		}
 
 		if ($options['resourcetype'] === null) {
@@ -277,12 +282,6 @@ class CScreenBuilder {
 				return new CScreenHttpTest($options);
 
 			case SCREEN_RESOURCE_PROBLEM:
-				if (array_key_exists('period', $options)) {
-					$options['data']['filter']['period'] = $options['period'];
-				}
-				if (array_key_exists('stime', $options)) {
-					$options['data']['filter']['stime'] = $options['stime'];
-				}
 				return new CScreenProblem($options);
 
 			default:
@@ -512,7 +511,7 @@ class CScreenBuilder {
 				elseif ($this->mode == SCREEN_MODE_EDIT) {
 					$item =[
 						(new CDiv(
-							(new CLink(_('Change'), $action))->addClass('empty_change_link')
+							(new CLink(_x('Change', 'verb'), $action))->addClass('empty_change_link')
 						))->addClass(ZBX_STYLE_CENTER)
 					];
 				}
@@ -646,15 +645,20 @@ class CScreenBuilder {
 	 * @param string $options['profileIdx']
 	 */
 	public static function insertScreenScrollJs(array $options = []) {
-		$options['timeline'] = empty($options['timeline']) ? '' : $options['timeline'];
-		$options['profileIdx'] = empty($options['profileIdx']) ? '' : $options['profileIdx'];
+		$options['timeline'] = array_key_exists('timeline', $options) ? $options['timeline'] : '';
+		$options['profileIdx'] = array_key_exists('profileIdx', $options) ? $options['profileIdx'] : '';
+		$options['profileIdx2'] = array_key_exists('profileIdx2', $options) ? $options['profileIdx2'] : 0;
 
 		$timeControlData = [
 			'id' => 'scrollbar',
 			'loadScroll' => 1,
 			'mainObject' => 1,
 			'periodFixed' => CProfile::get($options['profileIdx'].'.timelinefixed', 1),
-			'sliderMaximumTimePeriod' => ZBX_MAX_PERIOD
+			'sliderMaximumTimePeriod' => ZBX_MAX_PERIOD,
+			'profile' => [
+				'idx' => $options['profileIdx'],
+				'idx2' => $options['profileIdx2']
+			]
 		];
 
 		zbx_add_post_js('timeControl.addObject("scrollbar", '.zbx_jsvalue($options['timeline']).', '.zbx_jsvalue($timeControlData).');');
@@ -666,7 +670,7 @@ class CScreenBuilder {
 	 * @static
 	 */
 	public static function insertScreenRefreshTimeJs() {
-		zbx_add_post_js('timeControl.useTimeRefresh('.CWebUser::$data['refresh'].');');
+		zbx_add_post_js('timeControl.useTimeRefresh('.CWebUser::getRefresh().');');
 	}
 
 	/**
