@@ -38,9 +38,7 @@ class CScreenMap extends CScreenBase {
 		$this->insertFlickerfreeJs($map_data);
 
 		$output = [
-			(new CDiv())
-				->setId('map_'.$this->screenitem['screenitemid'])
-				->addStyle('overflow: hidden;')
+			(new CDiv())->setId('map_'.$this->screenitem['screenitemid'])
 		];
 
 		if ($this->mode == SCREEN_MODE_EDIT) {
@@ -54,6 +52,9 @@ class CScreenMap extends CScreenBase {
 			->setAttribute('data-timestamp', $this->timestamp)
 			->addStyle('position: relative;');
 
+		// Add map to additional wrapper to enable horizontal scrolling.
+		$div = (new CDiv($div))->addClass('sysmap-scroll-container');
+
 		return $div;
 	}
 }
