@@ -184,8 +184,8 @@ function DBconnect(&$error) {
 		$DB['DB'] = null;
 	}
 
-	if (!$result && !ZBX_SHOW_SQL_ERRORS) {
-		$error = _('SQL error. Please contact Zabbix administrator.');
+	if (!$result && !ZBX_SHOW_TECHNICAL_ERRORS) {
+		$error = _('System error occurred. Please contact Zabbix administrator.');
 	}
 
 	return $result;
@@ -366,22 +366,22 @@ function DBselect($query, $limit = null, $offset = 0) {
 	switch ($DB['TYPE']) {
 		case ZBX_DB_MYSQL:
 			if (!$result = mysqli_query($DB['DB'], $query)) {
-				sqlError('Error in query ['.$query.'] ['.mysqli_error($DB['DB']).']');
+				error('Error in query ['.$query.'] ['.mysqli_error($DB['DB']).']', 'sql');
 			}
 			break;
 		case ZBX_DB_POSTGRESQL:
 			if (!$result = pg_query($DB['DB'], $query)) {
-				sqlError('Error in query ['.$query.'] ['.pg_last_error().']');
+				error('Error in query ['.$query.'] ['.pg_last_error().']', 'sql');
 			}
 			break;
 		case ZBX_DB_ORACLE:
 			if (!$result = oci_parse($DB['DB'], $query)) {
 				$e = @oci_error();
-				sqlError('SQL error ['.$e['message'].'] in ['.$e['sqltext'].']');
+				error('SQL error ['.$e['message'].'] in ['.$e['sqltext'].']', 'sql');
 			}
 			elseif (!@oci_execute($result, ($DB['TRANSACTIONS'] ? OCI_DEFAULT : OCI_COMMIT_ON_SUCCESS))) {
 				$e = oci_error($result);
-				sqlError('SQL error ['.$e['message'].'] in ['.$e['sqltext'].']');
+				error('SQL error ['.$e['message'].'] in ['.$e['sqltext'].']', 'sql');
 			}
 			break;
 		case ZBX_DB_DB2:
@@ -392,11 +392,11 @@ function DBselect($query, $limit = null, $offset = 0) {
 
 			if (!$result = db2_prepare($DB['DB'], $query)) {
 				$e = @db2_stmt_errormsg($result);
-				sqlError('SQL error ['.$query.'] in ['.$e.']');
+				error('SQL error ['.$query.'] in ['.$e.']', 'sql');
 			}
 			elseif (true !== @db2_execute($result, $options)) {
 				$e = @db2_stmt_errormsg($result);
-				sqlError('SQL error ['.$query.'] in ['.$e.']');
+				error('SQL error ['.$query.'] in ['.$e.']', 'sql');
 				$result = false;
 			}
 			break;
@@ -441,7 +441,7 @@ function DBaddLimit($query, $limit = 0, $offset = 0) {
 
 	if ((isset($limit) && ($limit < 0 || !zbx_ctype_digit($limit))) || $offset < 0 || !zbx_ctype_digit($offset)) {
 		$moreDetails = isset($limit) ? ' Limit ['.$limit.'] Offset ['.$offset.']' : ' Offset ['.$offset.']';
-		sqlError('Incorrect parameters for limit and/or offset. Query ['.$query.']'.$moreDetails);
+		error('Incorrect parameters for limit and/or offset. Query ['.$query.']'.$moreDetails, 'sql');
 
 		return false;
 	}
@@ -480,22 +480,22 @@ function DBexecute($query, $skip_error_messages = 0) {
 	switch ($DB['TYPE']) {
 		case ZBX_DB_MYSQL:
 			if (!$result = mysqli_query($DB['DB'], $query)) {
-				sqlError('Error in query ['.$query.'] ['.mysqli_error($DB['DB']).']');
+				error('Error in query ['.$query.'] ['.mysqli_error($DB['DB']).']', 'sql');
 			}
 			break;
 		case ZBX_DB_POSTGRESQL:
 			if (!$result = (bool) pg_query($DB['DB'], $query)) {
-				sqlError('Error in query ['.$query.'] ['.pg_last_error().']');
+				error('Error in query ['.$query.'] ['.pg_last_error().']', 'sql');
 			}
 			break;
 		case ZBX_DB_ORACLE:
 			if (!$result = oci_parse($DB['DB'], $query)) {
 				$e = @oci_error();
-				sqlError('SQL error ['.$e['message'].'] in ['.$e['sqltext'].']');
+				error('SQL error ['.$e['message'].'] in ['.$e['sqltext'].']', 'sql');
 			}
 			elseif (!@oci_execute($result, ($DB['TRANSACTIONS'] ? OCI_DEFAULT : OCI_COMMIT_ON_SUCCESS))) {
 				$e = oci_error($result);
-				sqlError('SQL error ['.$e['message'].'] in ['.$e['sqltext'].']');
+				error('SQL error ['.$e['message'].'] in ['.$e['sqltext'].']', 'sql');
 			}
 			else {
 				$result = true; // function must return boolean
@@ -504,11 +504,11 @@ function DBexecute($query, $skip_error_messages = 0) {
 		case ZBX_DB_DB2:
 			if (!$result = db2_prepare($DB['DB'], $query)) {
 				$e = @db2_stmt_errormsg($result);
-				sqlError('SQL error ['.$query.'] in ['.$e.']');
+				error('SQL error ['.$query.'] in ['.$e.']', 'sql');
 			}
 			elseif (true !== @db2_execute($result)) {
 				$e = @db2_stmt_errormsg($result);
-				sqlError('SQL error ['.$query.'] in ['.$e.']');
+				error('SQL error ['.$query.'] in ['.$e.']', 'sql');
 			}
 			else {
 				$result = true; // function must return boolean
