@@ -560,20 +560,6 @@ function updateHostStatus($hostids, $status) {
 	]);
 }
 
-function get_application_by_applicationid($applicationid, $no_error_message = 0) {
-	$row = DBfetch(DBselect('SELECT a.* FROM applications a WHERE a.applicationid='.zbx_dbstr($applicationid)));
-
-	if ($row) {
-		return $row;
-	}
-
-	if ($no_error_message == 0) {
-		error(_s('No application with ID "%1$s".', $applicationid));
-	}
-
-	return false;
-}
-
 /**
  * Returns the farthest application ancestor for each given application.
  *
@@ -1075,3 +1061,83 @@ function getHostInventoryModes() {
 		HOST_INVENTORY_AUTOMATIC => _('Automatic')
 	];
 }
+
+/**
+ * Check if user has read permissions for hosts.
+ *
+ * @param array $hostids
+ *
+ * @return bool
+ */
+function isReadableHosts(array $hostids) {
+	return count($hostids) == API::Host()->get([
+		'countOutput' => true,
+		'hostids' => $hostids
+	]);
+}
+
+/**
+ * Check if user has read permissions for templates.
+ *
+ * @param array $templateids
+ *
+ * @return bool
+ */
+function isReadableTemplates(array $templateids) {
+	return count($templateids) == API::Template()->get([
+		'countOutput' => true,
+		'templateids' => $templateids
+	]);
+}
+
+/**
+ * Check if user has read permissions for hosts or templates.
+ *
+ * @param array $hostids
+ *
+ * @return bool
+ */
+function isReadableHostTemplates(array $hostids) {
+	$count = API::Host()->get([
+		'countOutput' => true,
+		'hostids' => $hostids
+	]);
+
+	if ($count == count($hostids)) {
+		return true;
+	}
+
+	$count += API::Template()->get([
+		'countOutput' => true,
+		'templateids' => $hostids
+	]);
+
+	return ($count == count($hostids));
+}
+
+/**
+ * Check if user has read permissions for hosts or templates.
+ *
+ * @param array $hostids
+ *
+ * @return bool
+ */
+function isWritableHostTemplates(array $hostids) {
+	$count = API::Host()->get([
+		'countOutput' => true,
+		'hostids' => $hostids,
+		'editable' => true
+	]);
+
+	if ($count == count($hostids)) {
+		return true;
+	}
+
+	$count += API::Template()->get([
+		'countOutput' => true,
+		'templateids' => $hostids,
+		'editable' => true
+	]);
+
+	return ($count == count($hostids));
+}
