@@ -226,8 +226,8 @@ $tranStrings = [
 		'Last month graph' => _('Last month graph'),
 		'Last week graph' => _('Last week graph'),
 		'Problems' => _('Problems'),
-		'Refresh time' => _('Refresh time'),
-		'Refresh time multiplier' => _('Refresh time multiplier'),
+		'Refresh interval' => _('Refresh interval'),
+		'Refresh interval multiplier' => _('Refresh interval multiplier'),
 		'Scripts' => _('Scripts'),
 		'Something went wrong. Please try again later!' => _('Something went wrong. Please try again later!'),
 		'Submap' => _('Submap'),
@@ -306,11 +306,18 @@ foreach ($files as $file) {
 	}
 }
 
-$jsLength = strlen($js);
-$etag = md5($jsLength);
-if (isset($_SERVER['HTTP_IF_NONE_MATCH']) && $_SERVER['HTTP_IF_NONE_MATCH'] == $etag) {
+$etag = md5($js);
+/**
+ * strpos function allow to check ETag value to fix cases when web server compression is used:
+ * - For case when apache server appends "-gzip" suffix to ETag.
+ *   https://bz.apache.org/bugzilla/show_bug.cgi?id=39727
+ *   https://bz.apache.org/bugzilla/show_bug.cgi?id=45023
+ * - For case when nginx v1.7.3+ server mark ETag as weak adding "W/" prefix
+ *   http://nginx.org/en/CHANGES
+ */
+if (array_key_exists('HTTP_IF_NONE_MATCH', $_SERVER) && strpos($_SERVER['HTTP_IF_NONE_MATCH'], $etag) !== false) {
 	header('HTTP/1.1 304 Not Modified');
-	header('ETag: '.$etag);
+	header('ETag: "'.$etag.'"');
 	exit;
 }
 
@@ -328,10 +335,10 @@ if (in_array('prototype.js', $files)) {
 		'};';
 }
 
-header('Content-type: text/javascript; charset=UTF-8');
+header('Content-Type: application/javascript; charset=UTF-8');
 // breaks if "zlib.output_compression = On"
 // header('Content-length: '.$jsLength);
 header('Cache-Control: public, must-revalidate');
-header('ETag: '.$etag);
+header('ETag: "'.$etag.'"');
 
 echo $js;
